declare const tktrErrors: {
    readonly INVALID_COMMAND: 400;
    readonly INVALID_ITEM: 400;
    readonly CREATE_CHECKOUT_SESSION_FAILED: 500;
    readonly RETRIEVE_CHECKOUT_SESSION_FAILED: 500;
    readonly NOT_IMPLEMENTED: 501;
};
type TKTRErrorType = keyof typeof tktrErrors;
declare class TKTRError extends Error {
    status: number;
    constructor(code: TKTRErrorType);
    toResponse(): Response;
}

declare function formatAmountForDisplay(amount: number, currency: string): string;
declare function formatAmountForStripe(amount: number, currency: string): number;

/**
 * BaseFactoryConfig
 *
 * Represents the base configuration for a store
 */
type BaseFactoryConfig = {
    currency: string;
};
/**
 * Item
 *
 * Represents an item that can be purchased
 */
type Item<TID extends string = string> = {
    id: TID;
    name: string;
    price: number;
    recurring?: {
        /**
         * Specifies billing frequency. Either `day`, `week`, `month` or `year`.
         */
        interval: "day" | "week" | "month" | "year";
        /**
         * The number of intervals between subscription billings. For example, `interval=month` and `interval_count=3` bills every 3 months. Maximum of three years interval allowed (3 years, 36 months, or 156 weeks).
         */
        interval_count?: number;
    };
};
/**
 * Might add more stuff in the future than diverges from `BaseFactoryConfig`
 */
type Store = BaseFactoryConfig;
/**
 * Factory function to create a store
 *
 * Nothing fancy for now, but it's better than to do `satisfies BaseFactoryConfig`
 */
declare function storeFactory<TBase extends BaseFactoryConfig>(baseConfig: Readonly<TBase>): Readonly<TBase>;
/**
 * Factory function to create items
 *
 * Nothing fancy for now, but it's better than to do `satisfies Item[]`
 */
declare function itemsFactory<TID extends string, TItems extends Item<TID>[]>(items: Readonly<TItems>): Readonly<TItems>;

export { type BaseFactoryConfig, type Item, type Store, TKTRError, formatAmountForDisplay, formatAmountForStripe, itemsFactory, storeFactory };
