// src/utils/error.ts
var tktrErrors = {
  INVALID_COMMAND: 400,
  INVALID_ITEM: 400,
  CREATE_CHECKOUT_SESSION_FAILED: 500,
  RETRIEVE_CHECKOUT_SESSION_FAILED: 500,
  NOT_IMPLEMENTED: 501
};
var TKTRError = class extends Error {
  status;
  constructor(code) {
    super(code);
    this.status = tktrErrors[code];
  }
  toResponse() {
    return new Response(JSON.stringify(
      { message: this.message }
    ), { status: this.status });
  }
};

// src/utils/stripe-helpers.ts
function formatAmountForDisplay(amount, currency) {
  let numberFormat = new Intl.NumberFormat(["en-US"], {
    style: "currency",
    currency,
    currencyDisplay: "symbol"
  });
  return numberFormat.format(amount);
}
function formatAmountForStripe(amount, currency) {
  let numberFormat = new Intl.NumberFormat(["en-US"], {
    style: "currency",
    currency,
    currencyDisplay: "symbol"
  });
  const parts = numberFormat.formatToParts(amount);
  let zeroDecimalCurrency = true;
  for (let part of parts) {
    if (part.type === "decimal") {
      zeroDecimalCurrency = false;
    }
  }
  return zeroDecimalCurrency ? amount : Math.round(amount * 100);
}

// src/store.ts
function storeFactory(baseConfig) {
  return baseConfig;
}
function itemsFactory(items) {
  return items;
}
export {
  TKTRError,
  formatAmountForDisplay,
  formatAmountForStripe,
  itemsFactory,
  storeFactory
};
